@@ -61,8 +61,8 @@ class dbthinger:
 		elif thisDatabaseType == database_type.MySQL:
 			self.mysql_db.useConnectionDetails(DB_USERNAME,DB_USERPWD,DB_HOST,DB_PORT,DB_NAME)
 
-		ans_save_connection_details = input('Save connection details (Y) ? ') or 'Y'
-		if ans_save_connection_details == 'Y':
+		ans_save_connection_details = input('Save connection details? (y/n) :') or 'y'
+		if ans_save_connection_details.upper() == 'Y':
 			f = open(configfilename,'w')
 
 			if thisDatabaseType == database_type.Postgres:
@@ -331,7 +331,7 @@ class schemawiz:
 		return_value = ''
 		self.loadcsvfile(csvfilename)
 		delimiter = self.lastcall_delimiter()
-
+		self.dbthings.mysql_db.connect()
 		if self.dbthings.mysql_db.does_table_exist(tablename):
 			self.dbthings.mysql_db.load_csv_to_table(csvfilename,tablename,withtruncate,delimiter)
 			rowcount = self.dbthings.mysql_db.queryone('SELECT COUNT(*) FROM ' + tablename)
@@ -429,6 +429,8 @@ class schemawiz:
 							self.datalinesize = total_linesize/10
 
 						self.SomeFileContents.append(line)
+						if (linecount>1000):
+							break
 				
 				#self.logger('file has ' + str(len(self.SomeFileContents)) + ' lines')
 				#self.logger('line size is ' + str(self.datalinesize) + ' ytes')
@@ -824,6 +826,10 @@ if __name__ == '__main__':
 
 	obj = schemawiz()
 
+
+	"""
+	print(obj.dbthings.postgres_db.does_table_exist('newtbl'))
+
 	# add any specific known date formats
 	#obj.dbthings.postgres_date_formats.append('Mon DD,YY')
 	if csvfilename != '':
@@ -833,7 +839,6 @@ if __name__ == '__main__':
 	print(r + ' created.')
 
 
-	"""
 
 	print('/* MySQL DDL - BEGIN ----- schemawiz().guess_mysql_ddl() ----- */ \n')
 	print(obj.guess_mysql_ddl('sample_csv'))
