@@ -3,9 +3,9 @@
 """
 from schemawizard_package.schemawizard import schemawiz
 
-csvfilename = 'tesla.csv'
+csvfilename = 'sample.csv'
 
-r = schemawiz().createload_mysql_from_csv(csvfilename)
+r = schemawiz().createload_mysql_from_csv(csvfilename,'sample2_csv')
 
 print(r + ' created.')
 
